OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календарь",
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Recipient" : "Хүлээн авагч",
    "Too many redirects. Aborting ..." : "Хэтэрхий олон дамжилттай байна. Үйлдлийг цуцлав...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Өөр сервэр бидэнд цагийн хуваарь луу хандах эрх өгсөнгүй (HTTP алдаа {%s})",
    "Error connecting to remote server" : "Алслагдсан сервэр рүү холбогдоход алдаа гарлаа",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Алслагдсан сервер дээрх нөөц рүү хандахад алдаа гарлаа. Энэ нь гэрчилгээ таарахгүй байх магадлалтай.",
    "Error requesting resource on remote server" : "Алслагдсан сервер дээрх нөөц рүү хандахад алдаа гарлаа",
    "Individual" : "Хувь хүний",
    "Group" : "Бүлэг",
    "Resource" : "Нөөц",
    "Room" : "Өрөө",
    "Unknown" : "Үл мэдэгдэх",
    "Required" : "Шаардлагатай",
    "Optional" : "Сайн дурын",
    "Does not attend" : "Оролцохгүй",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Та үл мэдэгдэх цагийн бүсд  ({tz}) байгаа тул UTC цагийн бүсийг ашиглана",
    "Please create a calendar first." : "Та эхлээд цагийн хуваариа үүсгэнэ үү.",
    "New event" : "Шинэ үйл явдал",
    "CalDAV address for clients" : "CalDAV хаяг",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Энэ цагийн хуваарь дахь зарим үйл явдал эвдэрсэн байна. JS console ашиглан дэлгэрэнгүй мэдээлэл авна уу.",
    "Share Calendar" : "Календарь түгээх",
    "Shared" : "Түгээсэн",
    "WebDAV address for subscriptions" : "WebDAV хаяг",
    "group" : "бүлэг",
    "Details" : "Дэлгэрэнгүй",
    "Attendees" : "Оролцогчид",
    "Reminders" : "Сануулагууд",
    "Repeating" : "Давталт",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Confirmed" : "Баталгаажсан",
    "Tentative" : "Урьдчилсан тов",
    "Cancelled" : "Цуцлагдсан",
    "Please add a title." : "Гарчиг оруулна уу.",
    "Please select a calendar." : "Цагийн хуваарь сонгоно уу.",
    "The event can not end before it starts." : "Үйл явдал эхлэхээсээ өмнө дуусах боломжгүй.",
    "Global" : "Нийтийн",
    "None" : "Аль нь ч биш",
    "Every day" : "Өдөр бүр",
    "Every week" : "Долоо хоног бүр",
    "Every month" : "Сар бүр",
    "Every year" : "Жил бүр",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "How about getting started by importing some calendars?" : "Цагийн хуваарь импортлон оруулж ирснээр ажлаа эхлэх үү?",
    "At time of event" : "Үйл явдлын эхлэх үед",
    "5 minutes before" : "5 минутын өмнө",
    "10 minutes before" : "10 минутын өмнө",
    "15 minutes before" : "15 минутын өмнө",
    "30 minutes before" : "30 минутын өмнө",
    "1 hour before" : "1 цагийн өмнө",
    "2 hours before" : "2 цагийн өмнө",
    "Custom" : "Дурын",
    "Audio" : "Аудио",
    "Email" : "Цахим шуудан",
    "Pop-up" : "поп-ап",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "цаг",
    "days" : "өдөр",
    "week" : "7 хоног",
    "before" : "өмнө",
    "start" : "эхлэх",
    "end" : "дуусах",
    "Editing reminders of unknown type not supported." : "Үл мэдэгдэх төрлийн санууллагыг засварлах боломжгүй.",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "{type} {time} before the event starts" : "{type} сануулга үйл явдал эхлэхээс өмнө {time}",
    "{type} {time} before the event ends" : "{type} сануулга үйл явдал дуусахаас өмнө {time}",
    "{type} {time} after the event starts" : "{type} сануулга үйл явдал эхэлсний дараа {time}",
    "{type} {time} after the event ends" : "{type} сануулга үйл явдал дууссаны дараа {time}",
    "{type} at the event's start" : "{type} үйл явдлын эхлэлд",
    "{type} at the event's end" : "{type} үйл явдлын төгсгөлд",
    "{type} at {time}" : "{type} нь {time}-д",
    "{calendar} shared by {owner}" : "{calendar}-ийг {owner} хуваалцсан",
    "Please enter a valid WebCal-URL" : "Зөв WebCal-ийн хаягийг оруулна уу",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Webcal проксид алдаа гарлаа. Зохицуулагчтай холбоо барьж тодруулна уу.",
    "Title of the Event" : "Үйл явдлын нэр",
    "Starts" : "Эхлэл",
    "Ends" : "Төгсгөл",
    "All day Event" : "Бүтэн өдрийн үйл явдал",
    "Delete" : "Устгах",
    "Cancel" : "Цуцлах",
    "More ..." : "Дэлгэрэнгүй ...",
    "Create" : "Үүсгэх",
    "Update" : "Шинэчлэх",
    "Close" : "Хаах",
    "Location" : "Байршил",
    "Description" : "Тайлбар",
    "Event status" : "Үйл явдлын статус",
    "Visibility when sharing" : "Хуваалцах үед харагдах эсэх",
    "Export" : "Экспорт",
    "%s has published the calendar %s" : "%s хэрэглэгч %s календарийг нийтлэв",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Таныг %s-г цагийн хуваарь  {boldstart}%s{boldend}.-д бичсэнийг бид сануулахыг хүслээ",
    "Click here to access it" : "Хандахын тулд энд дарна уу",
    "We wanted to inform you that %s has published the calendar %s." : "Таныг %s-г цагийн хуваарь %s-д бичсэнийг бид сануулахыг хүслээ",
    "Click on the link below to access it" : "Доорх холбоос дээр дарж хандана уу",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "Today" : "Өнөөдөр",
    "More" : "Дэлгэрэнгүй",
    "Edit" : "Засах",
    "Link" : "Холбоос",
    "iCal link" : "iCal холбоос",
    "Download" : "Татаж авах",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "can edit" : "засаж чадна",
    "Share link" : "Холбоос хуваалцах",
    "Public access" : "Нийтийн хандах эрх",
    "Email link to person" : "Холбоосыг цахим шуудангаар илгээх",
    "Send" : "Илгээх",
    "New Calendar" : "Шинэ цагийн хуваарь",
    "Name" : "Нэр",
    "New Subscription" : "Шинэ захиалга",
    "Go back" : "Буцах",
    "Go forward" : "Урагшлах",
    "Calendar does not exist" : "Цагийн хуваарь байхгүй байна",
    "Maybe you got a wrong link or the calendar was unshared?" : "Магадгүй та буруу холбоос авсан эсвэл цагийн хуваарийг хуваалцаагүй байх.",
    "Edit event" : "Үйл явдлыг засварлах",
    "Delete Event" : "Үйл явдлыг устгах",
    "Save Event" : "Үйл явдлыг хадгалах",
    "Time" : "Цаг",
    "Type" : "Төрөл",
    "Relative" : "Хамаарал",
    "Absolute" : "Тогтсон цагт",
    "Repeat" : "Давтах",
    "times every" : "удаа бүр",
    "Add" : "Нэмэх",
    "Email address of attendee" : "Оролцогчийн эшуудан хаяг",
    "Please add your email address in the personal settings in order to add attendees." : "Оролцогч нэмэхийн тулд хувийн тохиргоондоо эшуудангийн хаяг оруулна уу.",
    "from" : "Эхлэх нь",
    "to" : "Дуусах нь",
    "This event's repeating rule is not supported yet." : "Энэ үйл явдлын давтах дүрэм нь одоогоор дэмжигдээгүй байна.",
    "Support for advanced rules will be added with subsequent updates." : "Дараагийн шинэчлэлээр сайжруулсан дүрмүүдийг нэмж гаргах болно.",
    "Reset repeating rule" : "Давтах дүрмийг эхнээс нь эхлэх",
    "Repeat every ..." : "Давталт",
    "end repeat ..." : "давталтыг зогсоох",
    "times" : "удаа",
    "Import Calendars" : "Цагийн хуваарь оруулах",
    "Import canceled" : "Оруулж ирэхийг болисон",
    "Analyzing calendar" : "Цагийн хуваарийг шинжилж байна",
    "The file contains objects incompatible with the selected calendar" : "Файл нь тохирохгүй цагийн хуваарийн зүйл агуулсан байна",
    "New calendar" : "Шинэ цагийн хуваарь",
    "File is empty" : "Файл хоосон байна",
    "Import scheduled" : "Төлөвлөгдсөнийг импортлох",
    "%s shared the calendar <strong>%s</strong> with you" : "%s нь <strong>%s</strong> цагийн хуваарийг хуваалцсан",
    "Embed" : "Шигтгэх",
    "Iframe to integrate" : "Нэгтгэх Iframe",
    "Publish URL" : "URL-г нийтлэх",
    "Settings & import" : "Тохиргоо, импорт",
    "Skip simple event editor" : "Энгийн засварлагчийг алгасах",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Import calendar" : "Цагийн хуваарь оруулах",
    "No Calendars selected for import" : "Оруулж ирэх цагийн хуваарь сонгогдсонгүй",
    "Primary CalDAV address" : "Үндсэн CalDAV хаяг",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV хаяг",
    "Subscribe" : "Захиалах"
},
"nplurals=2; plural=(n != 1);");
